@@ -6,100 +6,106 @@ use unicode_segmentation::UnicodeSegmentation;
 use termion::event::Key;
 
 use crate::{
-    answer::{Answer, Prompt},
-    ask::{Question, QuestionOptions},
-    config::{PromptConfig, Transformer, DEFAULT_TRANSFORMER},
+    formatter::{BoolFormatter, DEFAULT_BOOL_FORMATTER},
     renderer::Renderer,
     terminal::Terminal,
 };
 
 const ERROR_MESSAGE: &str = "Invalid answer, try typing 'y' for yes or 'n' for no";
 
-#[derive(Clone)]
-pub struct ConfirmOptions<'a> {
-    message: &'a str,
-    default: Option<bool>,
-    help_message: Option<&'a str>,
-    transformer: Transformer,
+/// Presents a message to the user and asks them for a yes/no confirmation.
+#[derive(Copy, Clone)]
+pub struct Confirm<'a> {
+    /// Message to be presented to the user.
+    pub message: &'a str,
+
+    /// Default value, returned when the user input is empty.
+    pub default: Option<bool>,
+
+    /// Help message to be presented to the user.
+    pub help_message: Option<&'a str>,
+
+    /// Function that formats the user input and presents it to the user as the final rendering of the prompt.
+    pub formatter: BoolFormatter<'a>,
 }
 
-impl<'a> ConfirmOptions<'a> {
+impl<'a> Confirm<'a> {
+    /// Default formatter, [true] maps to "Yes" and [false] maps to "No".
+    pub const DEFAULT_FORMATTER: BoolFormatter<'a> = DEFAULT_BOOL_FORMATTER;
+
+    /// Creates a [Confirm] with the provided message and default configuration values.
     pub fn new(message: &'a str) -> Self {
         Self {
             message,
             default: None,
             help_message: None,
-            transformer: DEFAULT_TRANSFORMER,
+            formatter: Self::DEFAULT_FORMATTER,
         }
     }
 
+    /// Sets the default input.
     pub fn with_default(mut self, default: bool) -> Self {
         self.default = Some(default);
         self
     }
 
+    /// Sets the help message of the prompt.
     pub fn with_help_message(mut self, message: &'a str) -> Self {
         self.help_message = Some(message);
         self
     }
 
-    pub fn with_transformer(mut self, transformer: Transformer) -> Self {
-        self.transformer = transformer;
-        self
-    }
-}
-
-impl<'a> QuestionOptions<'a> for ConfirmOptions<'a> {
-    fn with_config(mut self, global_config: &'a PromptConfig) -> Self {
-        if let Some(transformer) = global_config.transformer {
-            self.transformer = transformer;
-        }
-        if let Some(help_message) = global_config.help_message {
-            self.help_message = Some(help_message);
-        }
-        if let Some(default) = global_config.confirm_default {
-            self.default = Some(default);
-        }
-
+    /// Sets the formatter
+    pub fn with_formatter(mut self, formatter: BoolFormatter<'a>) -> Self {
+        self.formatter = formatter;
         self
     }
 
-    fn into_question(self) -> Question<'a> {
-        Question::Confirm(self)
+    /// Parses the provided behavioral and rendering options and prompts
+    /// the CLI user for input according to them.
+    pub fn prompt(self) -> Result<bool, Box<dyn Error>> {
+        let terminal = Terminal::new()?;
+        let mut renderer = Renderer::new(terminal)?;
+        self.prompt_with_renderer(&mut renderer)
+    }
+
+    pub(in crate) fn prompt_with_renderer(
+        self,
+        renderer: &mut Renderer,
+    ) -> Result<bool, Box<dyn Error>> {
+        ConfirmPrompt::from(self).prompt(renderer)
     }
 }
 
-impl<'a> From<&'a str> for ConfirmOptions<'a> {
+impl<'a> From<&'a str> for Confirm<'a> {
     fn from(val: &'a str) -> Self {
-        ConfirmOptions::new(val)
+        Confirm::new(val)
     }
 }
 
-pub(in crate) struct Confirm<'a> {
+struct ConfirmPrompt<'a> {
     message: &'a str,
     error_state: bool,
     help_message: Option<&'a str>,
     default: Option<bool>,
-    renderer: Renderer,
     content: String,
-    transformer: Transformer,
+    formatter: BoolFormatter<'a>,
 }
 
-impl<'a> From<ConfirmOptions<'a>> for Confirm<'a> {
-    fn from(co: ConfirmOptions<'a>) -> Self {
+impl<'a> From<Confirm<'a>> for ConfirmPrompt<'a> {
+    fn from(co: Confirm<'a>) -> Self {
         Self {
             message: co.message,
             error_state: false,
             default: co.default,
             help_message: co.help_message,
-            renderer: Renderer::default(),
-            transformer: co.transformer,
+            formatter: co.formatter,
             content: String::new(),
         }
     }
 }
 
-impl<'a> Confirm<'a> {
+impl<'a> ConfirmPrompt<'a> {
     fn on_change(&mut self, key: Key) {
         match key {
             Key::Backspace => {
@@ -132,23 +138,13 @@ impl<'a> Confirm<'a> {
         }
     }
 
-    fn cleanup(&mut self, terminal: &mut Terminal, answer: &str) -> Result<(), Box<dyn Error>> {
-        self.renderer.reset_prompt(terminal)?;
-        self.renderer
-            .print_prompt_answer(terminal, &self.message, answer)?;
-
-        Ok(())
-    }
-}
-
-impl<'a> Prompt for Confirm<'a> {
-    fn render(&mut self, terminal: &mut Terminal) -> Result<(), std::io::Error> {
+    fn render(&mut self, renderer: &mut Renderer) -> Result<(), std::io::Error> {
         let prompt = &self.message;
 
-        self.renderer.reset_prompt(terminal)?;
+        renderer.reset_prompt()?;
 
         if self.error_state {
-            self.renderer.print_error_message(terminal, ERROR_MESSAGE)?;
+            renderer.print_error_message(ERROR_MESSAGE)?;
         }
 
         let default_message = self.default.map(|v| match v {
@@ -156,34 +152,30 @@ impl<'a> Prompt for Confirm<'a> {
             false => "y/N",
         });
 
-        self.renderer
-            .print_prompt(terminal, &prompt, default_message, Some(&self.content))?;
+        renderer.print_prompt(&prompt, default_message, Some(&self.content))?;
 
         if let Some(message) = self.help_message {
-            self.renderer.print_help(terminal, message)?;
+            renderer.print_help(message)?;
         }
 
-        terminal.flush()?;
+        renderer.flush()?;
 
         Ok(())
     }
 
-    fn prompt(mut self) -> Result<Answer, Box<dyn Error>> {
-        let mut terminal = Terminal::new()?;
-        terminal.cursor_hide()?;
-
-        let final_answer: Answer;
+    fn prompt(mut self, renderer: &mut Renderer) -> Result<bool, Box<dyn Error>> {
+        let final_answer: bool;
 
         loop {
-            self.render(&mut terminal)?;
+            self.render(renderer)?;
 
-            let key = terminal.read_key()?;
+            let key = renderer.read_key()?;
 
             match key {
                 Key::Ctrl('c') => bail!("Confirm interrupted by ctrl-c"),
                 Key::Char('\n') | Key::Char('\r') => match self.get_final_answer() {
                     Ok(answer) => {
-                        final_answer = Answer::Confirm(answer);
+                        final_answer = answer;
                         break;
                     }
                     Err(_) => {
@@ -195,11 +187,9 @@ impl<'a> Prompt for Confirm<'a> {
             }
         }
 
-        let transformed = (self.transformer)(&final_answer);
+        let formatted = (self.formatter)(final_answer);
 
-        self.cleanup(&mut terminal, &transformed)?;
-
-        terminal.cursor_show()?;
+        renderer.cleanup(&self.message, &formatted)?;
 
         Ok(final_answer)
     }
